pub fn sign(
signing_key: &SigningKey,
payload: &[u8],
timestamp: i64,
) -> SignatureExpand description
Sign a payload with the given key and timestamp.
The canonical signed message is SHA-256(payload || timestamp_le_bytes).
pub fn sign(
signing_key: &SigningKey,
payload: &[u8],
timestamp: i64,
) -> SignatureSign a payload with the given key and timestamp.
The canonical signed message is SHA-256(payload || timestamp_le_bytes).