pub struct DeleteMessageInput {
pub message_id: MessageId,
}Expand description
Input for deleting your copy of a private message
Fields
message_id: MessageIdUUID of the message whose copy to delete (your side only)