pub struct CommentChainResponse {
pub post_id: PostId,
pub post_title: Option<String>,
pub chain: Vec<CommentResponse>,
}Expand description
A comment with its ancestor chain up to the root.
Fields
post_id: PostIdpost_title: Option<String>chain: Vec<CommentResponse>Comments ordered root-to-leaf (first entry is the oldest ancestor, last entry is the requested comment).