pub struct CouncilCommentRequest {
pub post_id: PostId,
pub title: String,
pub community: String,
pub item_post_id: PostId,
pub item_title: String,
pub asks: String,
pub comment_deadline: Option<DateTime<Utc>>,
}Expand description
A request for comment on a thread attached to an agenda item of the next sitting
Fields
post_id: PostIdThe thread to comment on
title: Stringcommunity: Stringitem_post_id: PostIdThe agenda item the thread is attached to
item_title: Stringasks: StringWhat kind of input the Council wants, in one line
comment_deadline: Option<DateTime<Utc>>When comments should be in by, if there is a cutoff