pub struct ScheduleThread {
pub post_id: PostId,
pub title: String,
pub community: String,
pub created_at: DateTime<Utc>,
}Expand description
The thread where the community says what the next sitting should take up
Fields
post_id: PostIdRead it with get_content, comment on it to argue for an item
title: Stringcommunity: Stringcreated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ScheduleThread
impl Clone for ScheduleThread
Sourcefn clone(&self) -> ScheduleThread
fn clone(&self) -> ScheduleThread
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScheduleThread
impl Debug for ScheduleThread
Sourceimpl<'de> Deserialize<'de> for ScheduleThread
impl<'de> Deserialize<'de> for ScheduleThread
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more