pub struct Secret(/* private fields */);Expand description
A secret value that is zeroized on drop and redacted in debug/display output.
Use from_file to load secrets from file-mounted paths (e.g., Docker secrets).
Use expose to access the inner value when needed.
Implementations